==> ejc-probudget-api-3.0.0-20210914.025950-32-sources.jar: com/ejianc/business/plan/vo/RecalculateVO.java <==
package com.ejianc.business.plan.vo;

import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.util.Date;

/**
 * @author songlx
 * @version 1.0
 * @description: 计算VO
 * @date 2021/9/10
 */
public class RecalculateVO implements Serializable {

    private Long projectId; // 项目
    private Long budgetId; // 预算id

    private String startMonth; // 开始月份
    private String endMonth; // 结束月份
    private String monthEndDate; // 每月截止日期

    public RecalculateVO() {
    }

    public static RecalculateVO intsance(Long projectId, Long budgetId) {
        return new RecalculateVO(projectId, budgetId);
    }

    public RecalculateVO(Long projectId, Long budgetId) {
        this.projectId = projectId;
        this.budgetId = budgetId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getStartMonth() {
        return startMonth;
    }

    public void setStartMonth(String startMonth) {
        this.startMonth = startMonth;
    }

    public String getEndMonth() {
        return endMonth;
    }

    public void setEndMonth(String endMonth) {
        this.endMonth = endMonth;
    }

    public String getMonthEndDate() {
        return monthEndDate;
    }

    public void setMonthEndDate(String monthEndDate) {
        this.monthEndDate = monthEndDate;
    }


}

==> ejc-probudget-api-3.0.0-20210917.054305-48-sources.jar: com/ejianc/business/plan/vo/RecalculateVO.java <==
package com.ejianc.business.plan.vo;

import com.ejianc.business.material.vo.InstoreMaterialVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @author songlx
 * @version 1.0
 * @description: 计算VO
 * @date 2021/9/10
 */
public class RecalculateVO implements Serializable {

    private Long projectId; // 项目
    private Long budgetId; // 预算id

    private String startMonth; // 开始月份
    private String endMonth; // 结束月份
    private String monthEndDate; // 每月截止日期

    private Map<String, Object> queryParam; //查询到货量的


    private List<InstoreMaterialVO> instoreMaterialVOS;


    public RecalculateVO() {
    }

    public static RecalculateVO intsance(Long projectId, Long budgetId) {
        return new RecalculateVO(projectId, budgetId);
    }

    public RecalculateVO(Long projectId, Long budgetId) {
        this.projectId = projectId;
        this.budgetId = budgetId;
    }

    public List<InstoreMaterialVO> getInstoreMaterialVOS() {
        return instoreMaterialVOS;
    }

    public void setInstoreMaterialVOS(List<InstoreMaterialVO> instoreMaterialVOS) {
        this.instoreMaterialVOS = instoreMaterialVOS;
    }

    public Map<String, Object> getQueryParam() {
        return queryParam;
    }

    public void setQueryParam(Map<String, Object> queryParam) {
        this.queryParam = queryParam;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getStartMonth() {
        return startMonth;
    }

    public void setStartMonth(String startMonth) {
        this.startMonth = startMonth;
    }

    public String getEndMonth() {
        return endMonth;
    }

    public void setEndMonth(String endMonth) {
        this.endMonth = endMonth;
    }

    public String getMonthEndDate() {
        return monthEndDate;
    }

    public void setMonthEndDate(String monthEndDate) {
        this.monthEndDate = monthEndDate;
    }


}
